==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>看圖</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>看圖是一款外觀時尚，性能流暢的圖片查看工具。</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>張圖片</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>圖片資訊</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>基本資訊</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>詳細訊息</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>此檔案包含數頁，請使用 Evince 檢視全部頁面。</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>開啟資料夾</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>無權檢視圖片</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>未發現圖片文件</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>檔案名稱</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>類型</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>修改時間</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>尺寸</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>檔案大小</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>已擷取日期</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>曝光方式</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>曝光模式</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>曝光時間</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>閃光燈</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>光圈值</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>焦距</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>最大光圈</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>測光模式</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>白平衡</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>曝光補償</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>鏡頭型號</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>色彩空間</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>相機型號</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>圖片尺寸</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>标记</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>未縮放</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>將頁面縮放到圖片大小</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>將圖片縮放到頁面大小</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>縮放到：</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>毫米</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>公分</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>英寸</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>圖片位置</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>縮放</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>圖片設定</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>圖片設定</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>百葉窗</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>自內向外</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>自外向內</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>圓環</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>yyyy/MM/dd HH:mm:dd</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>請輸入圖片名稱</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>選擇資料夾</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>這個資料夾無法同步</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>加入資料夾</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>管理同步資料夾</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>資料夾列表為空</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>取消同步</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>張圖片</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>裝置移除</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>資料夾不存在</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>正在計算</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>圖片檢視</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>相簿管理</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>其他</translation>
    </message>
    <message>
        <source>View</source>
        <translation>檢視</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>開始幻燈片秀</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>結束幻燈片秀</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>從相簿移除</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>加到我的最愛</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>移除我的最愛</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>設定為桌布</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>開啟檔案位置</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>圖片資訊</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>向上捲動</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>向下捲動</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新增相簿</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重新命名</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>顯示快速鍵</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>退出全螢幕</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>放大圖片</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>縮小圖片</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打開</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>請輸入新快速鍵</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>快速鍵</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>圖片檢視</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>相簿管理</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>還原預設值</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>圖片檢視</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>開始幻燈片秀</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>結束幻燈片秀</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>列印</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>從相簿移除</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>加到我的最愛</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>移除我的最愛</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>設定為桌布</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>開啟檔案位置</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>圖片資訊</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新增相簿</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重新命名</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>離開</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>幻燈片秀設定</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>切換效果</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>間隔時間</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>切換間隔時間</translation>
    </message>
    <message>
        <source>second</source>
        <translation>秒</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>我的最愛</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1视图</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>縮放到視窗大小</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>圖片管理</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>我的最愛</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 大小</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>縮放到視窗大小</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>從我的最愛中移除</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>加到我的最愛</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>找不到圖片檔案</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>開啟圖片</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>未發現圖片文件</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>幻燈片秀設定</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>切換效果</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>間隔時間</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>快速鍵</translation>
    </message>
    <message>
        <source>View</source>
        <translation>圖片檢視</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>相簿管理</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>新增相簿</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>時間軸</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>加到相簿</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>加到新相簿</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>退出全螢幕</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻燈片秀</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>列印</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>從相簿移除</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>加到我的最愛</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>移除我的最愛</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>顯示導航視窗</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>隱藏導航視窗</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>設定為桌布</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>開啟檔案位置</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>圖片資訊</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>開啟圖片</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>所有圖片</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重新命名</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>畫板</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.8.15.orig.tar.xz: deepin-image-viewer-5.8.15/src/translations/deepin-image-viewer_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>未發現圖片文件</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>開啟圖片</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>圖片檢視</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>其他</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>退出全螢幕</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>識別文字</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>開始幻燈片秀</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重新命名</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>設定為桌布</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>開啟檔案位置</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>圖片資訊</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>放大圖片</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>縮小圖片</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打開</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>顯示快速鍵</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>看圖</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>看圖是一款外觀時尚，性能流暢的圖片查看工具。</translation>
    </message>
</context>
</TS>
